%define anolis_release 2
# Disable Qt by default
%bcond_with qt 0

# Do not build compose by default
%bcond_with compose 0

# Vala/Vapi support ( upstream disabled by default, probably explains why it the build breaks often )
%global vala 1

Summary: Utilities to generate, maintain and access the AppStream database
Name:    appstream
Version: 0.16.1
Release: %{anolis_release}%{?dist}

# lib LGPLv2+, tools GPLv2+
License: GPLv2+ and LGPLv2+
#URL:     http://www.freedesktop.org/wiki/Distributions/AppStream
URL:     https://github.com/ximion/appstream
Source0: http://www.freedesktop.org/software/appstream/releases/AppStream-%{version}.tar.xz

# https://github.com/Kekun/appstream/commit/bfa8fa6ac4ef645368a93384a6c16ac551a40922
Patch1000: 1000-Add-missing-standard-is-hidden-attribute-to-file-search-enumerator.patch

## upstream patches (lookaside cache)

## upstreamable patches

# needed for cmake auto-provides
BuildRequires: cmake
BuildRequires: meson >= 0.62
BuildRequires: gettext
BuildRequires: gperf
BuildRequires: gtk-doc
BuildRequires: intltool
BuildRequires: itstool
BuildRequires: libstemmer-devel
BuildRequires: pkgconfig(gio-2.0) >= 2.62
BuildRequires: pkgconfig(gio-unix-2.0) >= 2.62
BuildRequires: pkgconfig(glib-2.0) >= 2.62
BuildRequires: pkgconfig(gobject-2.0) >= 2.62
BuildRequires: pkgconfig(gobject-introspection-1.0) >= 1.56
BuildRequires: pkgconfig(libcurl) >= 7.62
BuildRequires: pkgconfig(libsystemd)
BuildRequires: pkgconfig(libxml-2.0)
BuildRequires: pkgconfig(xmlb) >= 0.3.6
BuildRequires: pkgconfig(yaml-0.1)
%if %{with compose}
BuildRequires: pkgconfig(cairo) >= 1.12
BuildRequires: pkgconfig(fontconfig)
BuildRequires: pkgconfig(freetype2)
BuildRequires: pkgconfig(gdk-pixbuf-2.0)
BuildRequires: pkgconfig(librsvg-2.0) >= 2.48
BuildRequires: pkgconfig(pango)
%endif
%if %{with qt}
BuildRequires: pkgconfig(Qt5Core)
# lrelease
BuildRequires: qt5-linguist
%endif
BuildRequires: sed
BuildRequires: vala
BuildRequires: xmlto

%description
AppStream makes it easy to access application information from the
AppStream database over a nice GObject-based interface.

%package devel
Summary:  Development files for %{name}
Requires: %{name} = %{version}-%{release}
Obsoletes: appstream-vala < 0.12.4-3
Provides: appstream-vala = %{version}-%{release}
%description devel
%{summary}.

%if %{with compose}
%package compose
Summary: Library for generating AppStream data
Requires: %{name} = %{version}-%{release}
%description compose
%{summary}.

%package compose-devel
Summary:  Development files for %{name}-compose library
Requires: %{name}-compose = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}
%description compose-devel
%{summary}.
%endif

%if %{with qt}
%package qt
Summary: Qt5 bindings for %{name}
Requires: %{name} = %{version}-%{release}
%description qt
%{summary}.

%package qt-devel
Summary:  Development files for %{name}-qt bindings
Requires: %{name}-qt = %{version}-%{release}
%description qt-devel
%{summary}.
%endif

%prep
%autosetup -n AppStream-%{version} -p1

%build
%{meson} \
%if %{with compose}
 -Dcompose=true \
%else
 -Dcompose=false \
%endif
%if %{with qt}
 -Dqt=true \
%endif
 -Dvapi=%{?vala:true}%{!?vala:false}

%{meson_build}

%install
%{meson_install}

mkdir -p %{buildroot}/var/cache/app-info/{icons,gv,xmls}
touch %{buildroot}/var/cache/app-info/cache.watch

%find_lang appstream

%if "%{?_metainfodir}" != "%{_datadir}/metainfo"
# move metainfo to right/legacy location
mkdir -p %{buildroot}%{_kf5_metainfodir}
mv %{buildroot}%{_datadir}/metainfo/*.xml \
   %{buildroot}%{_metainfodir}
%endif

%generate_compatibility_deps

%check
%{meson_test}

%posttrans
%{_bindir}/appstreamcli refresh --force >& /dev/null ||:

%transfiletriggerin -- %{_datadir}/app-info/xmls
%{_bindir}/appstreamcli refresh --force >& /dev/null ||:

%transfiletriggerpostun -- %{_datadir}/app-info/xmls
%{_bindir}/appstreamcli refresh --force >& /dev/null ||:

%files -f appstream.lang
%license COPYING
%dir %{abidir}
%{_bindir}/appstreamcli
%{abidir}/appstreamcli-option.list
%{_mandir}/man1/appstreamcli.1*
%config(noreplace) %{_sysconfdir}/appstream.conf
%dir %{_libdir}/girepository-1.0/
%{_libdir}/girepository-1.0/AppStream-1.0.typelib
%{_libdir}/libappstream.so.4*
%{_libdir}/libappstream.so.%{version}
%{abidir}/libappstream.dump
%{_metainfodir}/org.freedesktop.appstream.cli.*.xml
# put in -devel? -- rex
%{_datadir}/gettext/its/metainfo.*
%ghost /var/cache/app-info/cache.watch
%dir /var/cache/app-info/
%dir /var/cache/app-info/icons/
%dir /var/cache/app-info/gv/
%dir /var/cache/app-info/xmls/

%files devel
%{_includedir}/appstream/
%{_libdir}/libappstream.so
%{_libdir}/pkgconfig/appstream.pc
%dir %{_datadir}/gir-1.0/
%{_datadir}/gir-1.0/AppStream-1.0.gir
%if 0%{?vala}
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/appstream.deps
%{_datadir}/vala/vapi/appstream.vapi
%endif
%{_docdir}/appstream/html/
## symlink pointing to ^^, but need to take care, since rpm has
## trouble replacing dirs with symlinks, omit it for now -- rex
%exclude %{_datadir}/gtk-doc/html/appstream
# Maybe this should be split out? -- ngompa
%{_datadir}/installed-tests/appstream/metainfo-validate.test

%if %{with compose}
%files compose
%{_libexecdir}/appstreamcli-compose
%{_mandir}/man1/appstreamcli-compose.1*
%{_libdir}/libappstream-compose.so.0
%{_libdir}/libappstream-compose.so.%{version}
%{abidir}/libappstream-compose.dump
%{_libdir}/girepository-1.0/AppStreamCompose-1.0.typelib
%{_metainfodir}/org.freedesktop.appstream.compose.metainfo.xml

%files compose-devel
%{_includedir}/appstream-compose/
%{_libdir}/libappstream-compose.so
%{_libdir}/pkgconfig/appstream-compose.pc
%{_datadir}/gir-1.0/AppStreamCompose-1.0.gir
%dir %{_datadir}/gtk-doc/
%dir %{_datadir}/gtk-doc/html/
%{_datadir}/gtk-doc/html/appstream-compose
%endif

%if %{with qt}
%files qt
%{_libdir}/libAppStreamQt.so.2*
%{_libdir}/libAppStreamQt.so.%{version}

%files qt-devel
%{_includedir}/AppStreamQt/
%{_libdir}/cmake/AppStreamQt/
%{_libdir}/libAppStreamQt.so
%endif

%changelog
* Wed Apr 16 2025 Bo Ren <rb01097748@alibaba-inc.com> - 0.16.1-2
- Add missing standard::is-hidden attribute to file search enumerator

* Sun Feb 19 2023 Funda Wang <fundawang@yeah.net> - 0.16.1-1
- Import package for anolis 23
